@@ -188,9 +188,8 @@ class SessionRedisStore(SessionStore):
             value = self[key]
         except KeyError:
             return default
-        else:
-            del self[key]
-            return value
+        del self[key]
+        return value
 
     # endregion Access
 
